@@ -2,16 +2,12 @@ from __future__ import annotations
 
 import sys
 from pathlib import Path
+from typing import Literal
 
 import pytest
 
 IS_PY311 = sys.version_info[:2] >= (3, 11)
 
-if sys.version_info < (3, 8):
-    from typing_extensions import Literal
-else:
-    from typing import Literal
-
 
 @pytest.mark.parametrize("mode", ["normal", "xdist"])
 class TestFixture:
@@ -135,7 +131,7 @@ class TestFixture:
             pytest.importorskip("xdist")
             result = pytester.runpytest("-n1")
             expected_lines = ["1 worker [1 item]"]
-        expected_lines += ["* 1 passed, 3 xfailed, 2 subtests passed in *"]
+        expected_lines += ["* 1 passed, 2 subtests passed, 3 subtests xfailed in *"]
         result.stdout.fnmatch_lines(expected_lines)
 
     def test_typing_exported(
@@ -160,6 +156,62 @@ class TestFixture:
         expected_lines += ["* 1 passed *"]
         result.stdout.fnmatch_lines(expected_lines)
 
+    def test_no_subtests_reports(
+        self, pytester: pytest.Pytester, mode: Literal["normal", "xdist"]
+    ) -> None:
+        pytester.makepyfile(
+            """
+            import pytest
+
+            def test_foo(subtests):
+                for i in range(5):
+                    with subtests.test(msg="custom", i=i):
+                        pass
+        """
+        )
+        # Without `--no-subtests-reports`, subtests are reported normally.
+        result = pytester.runpytest("-v")
+        result.stdout.fnmatch_lines(
+            [
+                "*collected 1 item*",
+                "test_no_subtests_reports.py::test_foo * (i=0) SUBPASS*",
+                "*test_no_subtests_reports.py::test_foo PASSED*",
+                "* 1 passed, 5 subtests passed in*",
+            ]
+        )
+
+        # With `--no-subtests-reports`, passing subtests are no longer reported.
+        result = pytester.runpytest("-v", "--no-subtests-reports")
+        result.stdout.fnmatch_lines(
+            [
+                "*collected 1 item*",
+                "*test_no_subtests_reports.py::test_foo PASSED*",
+                "* 1 passed in*",
+            ]
+        )
+        result.stdout.no_fnmatch_line("*SUBPASS*")
+
+        # Rewrite the test file so the tests fail. Even with the flag, failed subtests are still reported.
+        pytester.makepyfile(
+            """
+            import pytest
+
+            def test_foo(subtests):
+                for i in range(5):
+                    with subtests.test(msg="custom", i=i):
+                        assert False
+        """
+        )
+        result = pytester.runpytest("-v", "--no-subtests-reports")
+        result.stdout.fnmatch_lines(
+            [
+                "*collected 1 item*",
+                "test_no_subtests_reports.py::test_foo * (i=0) SUBFAIL*",
+                "*test_no_subtests_reports.py::test_foo PASSED*",
+                "* 5 failed, 1 passed in*",
+            ]
+        )
+
 
 class TestSubTest:
     """
@@ -220,7 +272,7 @@ class TestSubTest:
                     "E  * AssertionError: 1 != 0",
                     "* T.test_foo [[]custom[]] (i=3) *",
                     "E  * AssertionError: 1 != 0",
-                    "* 2 failed, 1 passed in *",
+                    "* 2 failed, 1 passed, 3 subtests passed in *",
                 ]
             )
 
@@ -271,7 +323,7 @@ class TestSubTest:
                     "E  * AssertionError: 1 != 0",
                     "* T.test_foo [[]custom[]] (i=3) *",
                     "E  * AssertionError: 1 != 0",
-                    "* 2 failed, 1 passed in *",
+                    "* 2 failed, 1 passed, 3 subtests passed in *",
                 ]
             )
 
@@ -340,6 +392,181 @@ class TestSubTest:
                 ["collected 1 item", "* 3 xfailed, 1 passed in *"]
             )
 
+    @pytest.mark.parametrize("runner", ["pytest-normal"])
+    def test_only_original_skip_is_called(
+        self,
+        pytester: pytest.Pytester,
+        monkeypatch: pytest.MonkeyPatch,
+        runner: Literal["pytest-normal"],
+    ) -> None:
+        """Regression test for #173."""
+        monkeypatch.setenv("COLUMNS", "200")
+        p = pytester.makepyfile(
+            """
+            import unittest
+            from unittest import TestCase, main
+
+            @unittest.skip("skip this test")
+            class T(unittest.TestCase):
+                def test_foo(self):
+                    assert 1 == 2
+
+            if __name__ == '__main__':
+                main()
+        """
+        )
+        result = pytester.runpytest(p, "-v", "-rsf")
+        result.stdout.fnmatch_lines(
+            ["SKIPPED [1] test_only_original_skip_is_called.py:6: skip this test"]
+        )
+
+    @pytest.mark.parametrize("runner", ["unittest", "pytest-normal", "pytest-xdist"])
+    def test_skip_with_failure(
+        self,
+        pytester: pytest.Pytester,
+        monkeypatch: pytest.MonkeyPatch,
+        runner: Literal["unittest", "pytest-normal", "pytest-xdist"],
+    ) -> None:
+        monkeypatch.setenv("COLUMNS", "200")
+        p = pytester.makepyfile(
+            """
+            import pytest
+            from unittest import expectedFailure, TestCase, main
+
+            class T(TestCase):
+                def test_foo(self):
+                    for i in range(10):
+                        with self.subTest("custom message", i=i):
+                            if i < 4:
+                                self.skipTest(f"skip subtest i={i}")
+                            assert i < 4
+
+            if __name__ == '__main__':
+                main()
+        """
+        )
+        if runner == "unittest":
+            result = pytester.runpython(p)
+            if sys.version_info < (3, 11):
+                result.stderr.re_match_lines(
+                    [
+                        r"FAIL: test_foo \(__main__\.T\) \[custom message\] \(i=4\).*",
+                        r"FAIL: test_foo \(__main__\.T\) \[custom message\] \(i=9\).*",
+                        r"Ran 1 test in .*",
+                        r"FAILED \(failures=6, skipped=4\)",
+                    ]
+                )
+            else:
+                result.stderr.re_match_lines(
+                    [
+                        r"FAIL: test_foo \(__main__\.T\.test_foo\) \[custom message\] \(i=4\).*",
+                        r"FAIL: test_foo \(__main__\.T\.test_foo\) \[custom message\] \(i=9\).*",
+                        r"Ran 1 test in .*",
+                        r"FAILED \(failures=6, skipped=4\)",
+                    ]
+                )
+        elif runner == "pytest-normal":
+            result = pytester.runpytest(p, "-v", "-rsf")
+            result.stdout.re_match_lines(
+                [
+                    r"test_skip_with_failure.py::T::test_foo \[custom message\] \(i=0\) SUBSKIP \(skip subtest i=0\) .*",
+                    r"test_skip_with_failure.py::T::test_foo \[custom message\] \(i=3\) SUBSKIP \(skip subtest i=3\) .*",
+                    r"test_skip_with_failure.py::T::test_foo \[custom message\] \(i=4\) SUBFAIL .*",
+                    r"test_skip_with_failure.py::T::test_foo \[custom message\] \(i=9\) SUBFAIL .*",
+                    "test_skip_with_failure.py::T::test_foo PASSED .*",
+                    r"[custom message] (i=0) SUBSKIP [1] test_skip_with_failure.py:5: skip subtest i=0",
+                    r"[custom message] (i=0) SUBSKIP [1] test_skip_with_failure.py:5: skip subtest i=3",
+                    r"[custom message] (i=4) SUBFAIL test_skip_with_failure.py::T::test_foo - AssertionError: assert 4 < 4",
+                    r"[custom message] (i=9) SUBFAIL test_skip_with_failure.py::T::test_foo - AssertionError: assert 9 < 4",
+                    r".* 6 failed, 1 passed, 4 skipped in .*",
+                ]
+            )
+        else:
+            pytest.xfail("Not producing the expected results (#5)")
+            result = pytester.runpytest(p)  # type:ignore[unreachable]
+            result.stdout.fnmatch_lines(
+                ["collected 1 item", "* 3 skipped, 1 passed in *"]
+            )
+
+    @pytest.mark.parametrize("runner", ["unittest", "pytest-normal", "pytest-xdist"])
+    def test_skip_with_failure_and_non_subskip(
+        self,
+        pytester: pytest.Pytester,
+        monkeypatch: pytest.MonkeyPatch,
+        runner: Literal["unittest", "pytest-normal", "pytest-xdist"],
+    ) -> None:
+        monkeypatch.setenv("COLUMNS", "200")
+        p = pytester.makepyfile(
+            """
+            import pytest
+            from unittest import expectedFailure, TestCase, main
+
+            class T(TestCase):
+                def test_foo(self):
+                    for i in range(10):
+                        with self.subTest("custom message", i=i):
+                            if i < 4:
+                                self.skipTest(f"skip subtest i={i}")
+                            assert i < 4
+                    self.skipTest(f"skip the test")
+
+            if __name__ == '__main__':
+                main()
+        """
+        )
+        if runner == "unittest":
+            result = pytester.runpython(p)
+            if sys.version_info < (3, 11):
+                result.stderr.re_match_lines(
+                    [
+                        r"FAIL: test_foo \(__main__\.T\) \[custom message\] \(i=4\).*",
+                        r"FAIL: test_foo \(__main__\.T\) \[custom message\] \(i=9\).*",
+                        r"Ran 1 test in .*",
+                        r"FAILED \(failures=6, skipped=5\)",
+                    ]
+                )
+            else:
+                result.stderr.re_match_lines(
+                    [
+                        r"FAIL: test_foo \(__main__\.T\.test_foo\) \[custom message\] \(i=4\).*",
+                        r"FAIL: test_foo \(__main__\.T\.test_foo\) \[custom message\] \(i=9\).*",
+                        r"Ran 1 test in .*",
+                        r"FAILED \(failures=6, skipped=5\)",
+                    ]
+                )
+        elif runner == "pytest-normal":
+            result = pytester.runpytest(p, "-v", "-rsf")
+            # The `(i=0)` is not correct but it's given by pytest `TerminalReporter` without `--no-fold-skipped`
+            result.stdout.re_match_lines(
+                [
+                    r"test_skip_with_failure_and_non_subskip.py::T::test_foo \[custom message\] \(i=4\) SUBFAIL .*",
+                    r"test_skip_with_failure_and_non_subskip.py::T::test_foo SKIPPED \(skip the test\)",
+                    r"\[custom message\] \(i=0\) SUBSKIP \[1\] test_skip_with_failure_and_non_subskip.py:5: skip subtest i=3",
+                    r"\[custom message\] \(i=0\) SUBSKIP \[1\] test_skip_with_failure_and_non_subskip.py:5: skip the test",
+                    r"\[custom message\] \(i=4\) SUBFAIL test_skip_with_failure_and_non_subskip.py::T::test_foo",
+                    r".* 6 failed, 5 skipped in .*",
+                ]
+            )
+            # Check with `--no-fold-skipped` (which gives the correct information).
+            if sys.version_info >= (3, 10) and pytest.version_tuple[:2] >= (8, 3):
+                result = pytester.runpytest(p, "-v", "--no-fold-skipped", "-rsf")
+                result.stdout.re_match_lines(
+                    [
+                        r"test_skip_with_failure_and_non_subskip.py::T::test_foo \[custom message\] \(i=4\) SUBFAIL .*",
+                        r"test_skip_with_failure_and_non_subskip.py::T::test_foo SKIPPED \(skip the test\).*",
+                        r"\[custom message\] \(i=3\) SUBSKIP test_skip_with_failure_and_non_subskip.py::T::test_foo - Skipped: skip subtest i=3",
+                        r"SKIPPED test_skip_with_failure_and_non_subskip.py::T::test_foo - Skipped: skip the test",
+                        r"\[custom message\] \(i=4\) SUBFAIL test_skip_with_failure_and_non_subskip.py::T::test_foo",
+                        r".* 6 failed, 5 skipped in .*",
+                    ]
+                )
+        else:
+            pytest.xfail("Not producing the expected results (#5)")
+            result = pytester.runpytest(p)  # type:ignore[unreachable]
+            result.stdout.fnmatch_lines(
+                ["collected 1 item", "* 3 skipped, 1 passed in *"]
+            )
+
 
 class TestCapture:
     def create_file(self, pytester: pytest.Pytester) -> None:
